@@ -20,7 +20,7 @@
 
 class CPUStatus: public YWindow, public YTimerListener {
 public:
-    CPUStatus(const char *CpuCommand, YWindow *aParent = 0);
+    CPUStatus(YWindow *aParent = 0);
     virtual ~CPUStatus();
     
     virtual void paint(Graphics &g, int x, int y, unsigned int width, unsigned int height);
@@ -38,7 +38,6 @@ private:
     long last_cpu[IWM_STATES];
     YColor *color[IWM_STATES];
     YTimer *fUpdateTimer;
-    const char * fCPUCommand;
 };
 
 #endif
