@@ -197,7 +197,7 @@ void MailCheck::socketDataRead(char *buf, int len) {
     }
     
     if (protocol == POP3) {
-        if (strncmp(bf, "+OK ", 4) != 0) {
+        if (strncmp(bf, "+OK ", 3) != 0) {
             error();
             return ;
         }
@@ -403,7 +403,7 @@ void MailBoxStatus::mailChecked(MailBoxState mst, long count) {
     else {
         char s[128];
         if (count != -1) {
-            snprintf(s, sizeof(s),
+            sprintf(s,
                     count == 1 ?
                     _("%ld mail message.") :
                     _("%ld mail messages."), // too hard to do properly
