@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 #include "yfull.h"
@@ -486,7 +486,8 @@ void YFrameWindow::layoutButtons() {
 
 void YFrameWindow::layoutResizeIndicators() {
     if (((frameDecors() & (fdResize | fdBorder)) == (fdResize | fdBorder)) &&
-        !isRollup() && !isMinimized()) {
+        !isRollup() && !isMinimized() && (frameFunctions() & ffResize)) 
+    {
         if (!indicatorsVisible) {
             indicatorsVisible = 1;
 
