@@ -1,10 +1,10 @@
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <X11/Xlocale.h>
 #include "config.h"
 #include "ylib.h"
+#include "ypixbuf.h"
 #include <X11/Xatom.h>
 #include "ylistbox.h"
 #include "yscrollview.h"
@@ -13,6 +13,7 @@
 #include "sysdep.h"
 #include "yaction.h"
 #include "ymenuitem.h"
+#include "ylocale.h"
 #include "prefs.h"
 
 //#define DUMP
@@ -492,66 +493,16 @@ node *parse(FILE *fp, int flags, node *parent, node *&nextsub, node::node_type &
     return f;
 }
 
-YIcon *file = 0;
-
 extern Atom _XA_WIN_ICONS;
 
 class HTextView: public YWindow,
     public YScrollBarListener, public YScrollable, public YActionListener
 {
 public:
-    HTextView(HTListener *fL, YScrollView *v, YWindow *parent):
-	YWindow(parent), view(v), listener(fL) {
-        view = v;
-        fVerticalScroll = view->getVerticalScrollBar();
-        fVerticalScroll->setScrollBarListener(this);
-        fHorizontalScroll = view->getHorizontalScrollBar();
-        fHorizontalScroll->setScrollBarListener(this);
-        //setBitGravity(NorthWestGravity);
-        tx = ty = 0;
-        conWidth = conHeight = 0;
+    HTextView(HTListener *fL, YScrollView *v, YWindow *parent);
+    ~HTextView() {}
 
-        prevURL = nextURL = contentsURL = 0;
-
-        //font = YFont::getFont("9x15");
-        //font = YFont::getFont("-adobe-helvetica-medium-r-normal--10-100-75-75-p-56-iso8859-1");
-        //font = YFont::getFont("-adobe-helvetica-medium-r-normal--*-140-*-*-*-*-iso8859-1");
-        //-adobe-helvetica-bold-o-normal--11-80-100-100-p-60-iso8859-1
-        //font = YFont::getFont("-adobe-helvetica-medium-r-normal--8-80-75-75-p-46-iso8859-1");
-        //font = YFont::getFont("-adobe-helvetica-medium-r-normal--24-240-75-75-p-130-iso8859-1");
-        font = YFont::getFont("-adobe-helvetica-medium-r-normal--12-120-75-75-p-67-iso8859-1");
-        //font = YFont::getFont("-adobe-helvetica-medium-r-normal--11-80-100-100-p-56-iso8859-1");
-        //font = YFont::getFont("-adobe-helvetica-bold-r-normal--12-120-75-75-p-70-iso8859-1");
-        normalFg = new YColor("rgb:00/00/00");
-        hrFg = new YColor("rgb:80/80/80");
-        linkFg = new YColor("rgb:00/00/CC");
-        bg = new YColor("rgb:CC/CC/CC");
-        testBg = new YColor("rgb:40/40/40");
-
-        actionClose = new YAction();
-        actionNone = new YAction();
-        actionPrev = new YAction();
-        actionNext = new YAction();
-        actionContents = new YAction();
-
-        menu = new YMenu();
-        menu->setActionListener(this);
-        menu->addItem(_("Back"), 0, _("Alt+Left"), actionNone)->setEnabled(false);
-        menu->addItem(_("Forward"), 0, _("Alt+Right"), actionNone)->setEnabled(false);
-        menu->addSeparator();
-        prevItem = menu->addItem(_("Previous"), 0, "", actionPrev);
-        nextItem = menu->addItem(_("Next"), 0, "", actionNext);
-        menu->addSeparator();
-        contentsItem = menu->addItem(_("Contents"), 0, "", actionContents);
-        menu->addItem(_("Index"), 0, "", actionNone)->setEnabled(false);
-        menu->addSeparator();
-        menu->addItem(_("Close"), 0, _("Ctrl+Q"), actionClose);
-    }
-
-    ~HTextView() {
-    }
-
-    void HTextView::find_link(node *n);
+    void find_link(node *n);
 
     void setData(node *root) {
         fRoot = root;
@@ -639,9 +590,11 @@ public:
             listener->activateURL(contentsURL);
     }
 
-    virtual void configure(int x, int y, unsigned int width, unsigned int height) {
-        YWindow::configure(x, y, width, height);
-        layout();
+    virtual void configure(const int x, const int y, 
+			   const unsigned width, const unsigned height, 
+			   const bool resized) {
+        YWindow::configure(x, y, width, height, resized);
+        if (resized) layout();
    }
 private:
     node *fRoot;
@@ -673,6 +626,54 @@ private:
     YMenuItem *prevItem, *nextItem, *contentsItem;
 };
 
+HTextView::HTextView(HTListener *fL, YScrollView *v, YWindow *parent):
+    YWindow(parent), fRoot(NULL), view(v), listener(fL) {
+    view = v;
+    fVerticalScroll = view->getVerticalScrollBar();
+    fVerticalScroll->setScrollBarListener(this);
+    fHorizontalScroll = view->getHorizontalScrollBar();
+    fHorizontalScroll->setScrollBarListener(this);
+    //setBitGravity(NorthWestGravity);
+    tx = ty = 0;
+    conWidth = conHeight = 0;
+
+    prevURL = nextURL = contentsURL = 0;
+
+    //font = YFont::getFont("9x15");
+    //font = YFont::getFont("-adobe-helvetica-medium-r-normal--10-100-75-75-p-56-iso8859-1");
+    //font = YFont::getFont("-adobe-helvetica-medium-r-normal--*-140-*-*-*-*-iso8859-1");
+    //-adobe-helvetica-bold-o-normal--11-80-100-100-p-60-iso8859-1
+    //font = YFont::getFont("-adobe-helvetica-medium-r-normal--8-80-75-75-p-46-iso8859-1");
+    //font = YFont::getFont("-adobe-helvetica-medium-r-normal--24-240-75-75-p-130-iso8859-1");
+    font = YFont::getFont("-adobe-helvetica-medium-r-normal--12-120-75-75-p-67-iso8859-1");
+    //font = YFont::getFont("-adobe-helvetica-medium-r-normal--11-80-100-100-p-56-iso8859-1");
+    //font = YFont::getFont("-adobe-helvetica-bold-r-normal--12-120-75-75-p-70-iso8859-1");
+    normalFg = new YColor("rgb:00/00/00");
+    hrFg = new YColor("rgb:80/80/80");
+    linkFg = new YColor("rgb:00/00/CC");
+    bg = new YColor("rgb:CC/CC/CC");
+    testBg = new YColor("rgb:40/40/40");
+
+    actionClose = new YAction();
+    actionNone = new YAction();
+    actionPrev = new YAction();
+    actionNext = new YAction();
+    actionContents = new YAction();
+
+    menu = new YMenu();
+    menu->setActionListener(this);
+    menu->addItem(_("Back"), 0, _("Alt+Left"), actionNone)->setEnabled(false);
+    menu->addItem(_("Forward"), 0, _("Alt+Right"), actionNone)->setEnabled(false);
+    menu->addSeparator();
+    prevItem = menu->addItem(_("Previous"), 0, "", actionPrev);
+    nextItem = menu->addItem(_("Next"), 0, "", actionNext);
+    menu->addSeparator();
+    contentsItem = menu->addItem(_("Contents"), 0, "", actionContents);
+    menu->addItem(_("Index"), 0, "", actionNone)->setEnabled(false);
+    menu->addSeparator();
+    menu->addItem(_("Close"), 0, _("Ctrl+Q"), actionClose);
+}
+
 node *HTextView::find_node(node *n, int x, int y, node *&anchor, node::node_type type) {
 
     while (n) {
@@ -872,7 +873,7 @@ void HTextView::layout(node *parent, node *n1, int left, int right, int &x, int
 
                         *pwrap = new text_node(b, c - b, x, y, wc, font->height());
                         pwrap = &((*pwrap)->next);
-                        if (y + font->height() > h)
+                        if (y + (int)font->height() > h)
                             h = y + font->height();
 
                         x += wc;
@@ -1135,12 +1136,16 @@ public:
         setTitle(fPath);
 	setClassHint("browser", "IceHelp");
 
-        file = getIcon("file");
-        Pixmap icons[4];
-        icons[0] = file->small()->pixmap();
-        icons[1] = file->small()->mask();
-        icons[2] = file->large()->pixmap();
-        icons[3] = file->large()->mask();
+        YIcon * file_icon(getIcon("file"));
+        small_icon = new YPixmap(*file_icon->small());
+        large_icon = new YPixmap(*file_icon->large());
+        delete file_icon;
+
+        Pixmap icons[4] = {
+            small_icon->pixmap(), small_icon->mask(),
+            large_icon->pixmap(), large_icon->mask()
+        };
+
         XChangeProperty(app->display(), handle(),
                         _XA_WIN_ICONS, XA_PIXMAP,
                         32, PropModeReplace,
@@ -1185,9 +1190,11 @@ public:
 #endif
     }
 
-    virtual void configure(int x, int y, unsigned int width, unsigned int height) {
-        YWindow::configure(x, y, width, height);
-        scroll->setGeometry(0, 0, width, height);
+    virtual void configure(const int x, const int y, 
+			   const unsigned width, const unsigned height, 
+			   const bool resized) {
+        YWindow::configure(x, y, width, height, resized);
+        if (resized) scroll->setGeometry(0, 0, width, height);
     }
 
     virtual void handleClose() {
@@ -1200,6 +1207,8 @@ private:
 
     HTextView *view;
     YScrollView *scroll;
+    YPixmap *small_icon;
+    YPixmap *large_icon;
 };
 
 void HTextView::handleClick(const XButtonEvent &up, int /*count*/) {
@@ -1225,20 +1234,24 @@ void HTextView::handleClick(const XButtonEvent &up, int /*count*/) {
 }
 
 int main(int argc, char **argv) {
-#ifdef I18N
-    char *loc = setlocale(LC_ALL, "");
-    if (loc == NULL || !strcmp(loc, "C") || !strcmp(loc, "POSIX"))
-        multiByte = false;
-    else multiByte = true;
-#endif
+    YLocale locale;
     YApplication app(&argc, &argv);
 
-    if (argc > 1) {
+// !!! very, very dirty hack until we have theme support IceApps...
+    scrollBarWidth = scrollBarHeight = 16;	
+
+    if (argc == 2) {
         FileView *view = new FileView(argv[1]);
         view->show();
 
         return app.mainLoop();
     }
+    
+    printf(_("Usage: %s FILENAME\n\n"
+	     "A very simple HTML browser displaying the document specified "
+	     "by FILENAME.\n\n"),
+	     YApplication::Name);
+    return 1;
 }
 
 void FileView::loadFile() {
