@@ -1,9 +1,10 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997,1998 Marko Macek
+ * Copyright (C) 1997-2001 Marko Macek
  */
 
+#include "config.h"
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
@@ -27,6 +28,8 @@
 #define GUI_EVENT_NAMES
 #include "guievent.h"
 
+#include "intl.h"
+
 char *displayName = 0;
 Display *display = 0;
 Window root = 0;
@@ -34,8 +37,14 @@ Window root = 0;
 Atom XA_IcewmWinOptHint;
 
 int main(int argc, char **argv) {
+
+#ifdef ENABLE_NLS
+    bindtextdomain(PACKAGE, LOCDIR);
+    textdomain(PACKAGE);
+#endif
+
     if (argc < 4) {
-        fprintf(stderr, "Usage: icewmhint [class.instance] option arg\n");
+        fputs(_("Usage: icewmhint [class.instance] option arg\n"), stderr);
         exit(1);
     }
 
@@ -51,7 +60,8 @@ int main(int argc, char **argv) {
     unsigned char *hint = (unsigned char *)malloc(hint_len);
 
     if (hint == 0) {
-        fprintf(stderr, "Out of memory (len=%d).", hint_len);
+        fprintf(stderr, _("Out of memory (len=%d)."), hint_len);
+        fputs("\n", stderr);
         exit(1);
     }
 
@@ -60,7 +70,11 @@ int main(int argc, char **argv) {
     memcpy(hint + clsin_len + option_len, arg, arg_len);
 
     if (!(display = XOpenDisplay(displayName))) {
-        fprintf(stderr, "Can't open display: %s", displayName);
+        fprintf(stderr,
+                _("Can't open display: %s. "
+                  "X must be running and $DISPLAY set."),
+                displayName ? displayName : _("<none>"));
+        fputs("\n", stderr);
         exit(1);
     }
 
