@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 
@@ -359,7 +359,7 @@ void YFrameWindow::drawMoveSizeFX(int x, int y, int w, int h, bool /*interior*/)
     
     if (moveSizeGeomLabels & 0x7f) {
 	static char label[50];
-	snprintf(label, sizeof(label), "%dx%d+%d+%d", w, h, x, y);
+	sprintf(label, "%dx%d+%d+%d", w, h, x, y);
 
 	int const tw(font->textWidth(label));
 	int const th(font->height());
@@ -1052,9 +1052,13 @@ void YFrameWindow::constrainMouseToWorkspace(int &x, int &y) {
 bool YFrameWindow::canSize(bool horiz, bool vert) {
     if (isRollup())
         return false;
+    if (!(frameFunctions() & ffResize))
+        return false;
+#if 0
 #ifndef NO_MWM_HINTS
     if (!(client()->mwmFunctions() & MWM_FUNC_RESIZE))
         return false;
+#endif
 #endif
     if (!sizeMaximized) {
         if ((!vert || isMaximizedVert()) &&
@@ -1065,9 +1069,13 @@ bool YFrameWindow::canSize(bool horiz, bool vert) {
 }
 
 bool YFrameWindow::canMove() {
+    if (!(frameFunctions() & ffMove))
+        return false;
+#if 0
 #ifndef NO_MWM_HINTS
     if (!(client()->mwmFunctions() & MWM_FUNC_MOVE))
         return false;
+#endif
 #endif
     return true;
 }
