@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 
@@ -83,7 +83,7 @@ void ThemesMenu::findThemes(const char *path, YMenu *container) {
     bool isFirst(true);
 
     int dplen(strlen(path));
-    char *npath(NULL), *dpath(NULL);
+    char *npath = NULL, *dpath = NULL;
 
     if (dplen == 0 || path[dplen - 1] != '/') {
         npath = strJoin(path, "/", NULL);
@@ -115,7 +115,8 @@ void ThemesMenu::findThemes(const char *path, YMenu *container) {
             delete [] npath;
 
 	    char *subdir(strJoin(dpath, de->d_name, NULL));
-	    if (im && subdir) findThemeAlternatives(subdir, im);
+            if (im && subdir) findThemeAlternatives(subdir, im);
+            delete [] subdir;
 	}
 
 	closedir(dir);
