@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 #include "yfull.h"
@@ -34,6 +34,7 @@
 #include "ypixbuf.h"
 #include "ylocale.h"
 #include <stdio.h>
+#include <sys/resource.h>
 
 #include "intl.h"
 
@@ -614,9 +615,14 @@ static void initPixmaps() {
     if (buttonAPixmap)
 	buttonAPixmap->replicate(true, false);
 
-    YColor * bColor(DesktopBackgroundColor && DesktopBackgroundColor[0]
-		  ? new YColor(DesktopBackgroundColor)
-		  : YColor::black);
+    YColor * bColor((DesktopBackgroundColor && DesktopBackgroundColor[0])
+                    ? new YColor(DesktopBackgroundColor)
+                    : 0);
+
+    wmapp->bgColor = bColor;
+
+    if (bColor == 0)
+        bColor = YColor::black;
 
     unsigned long const bPixel(bColor->pixel());
     bool handleBackground(false);
@@ -879,6 +885,28 @@ void runRestart(const char *str, const char **args) {
     ///!!! problem with repeated SIGHUP for restart...
     app->resetSignals();
 
+#if 1   /* for now, some debugging code */
+        {
+            /* close all files */
+
+            int             i, max = 1024;
+            struct rlimit   lim;
+
+            if (getrlimit(RLIMIT_NOFILE, &lim) == 0)
+                max = lim.rlim_max;
+
+            for (i = 3; i < max; i++) {
+                int fl;
+                if (fcntl(i, F_GETFD, &fl) == 0) {
+                    if (!(fl & FD_CLOEXEC)) {
+                        warn("file descriptor still open: %d. Please report a bug!", i);
+                    }
+                }
+                close (i);
+            }
+        }
+#endif
+
     if (str) {
         if (args) {
             execvp(str, (char * const *) args);
@@ -949,6 +977,8 @@ void YWMApp::actionPerformed(YAction *action, unsigned int /*modifiers*/) {
                 msgbox->setMsgBoxListener(this);
                 msgbox->showFocused();
             }
+#else
+            logout();
 #endif
         }
     } else if (action == actionCancelLogout) {
@@ -1054,6 +1084,7 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
     XSetErrorHandler(handler);
 
     fLogoutMsgBox = 0;
+    bgColor = 0;
 
     initAtoms();
     initActions();
@@ -1137,7 +1168,7 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
     if (showTaskBar) {
         taskBar = new TaskBar(manager);
         if (taskBar)
-            taskBar->showBar(true);
+	  taskBar->showBar(true);
     } else {
         taskBar = 0;
     }
@@ -1214,6 +1245,7 @@ YWMApp::~YWMApp() {
     delete menuselPixbuf;
     delete menusepPixbuf;
 #endif
+    delete bgColor;
 
 
 #ifdef CONFIG_TASKBAR
@@ -1332,9 +1364,9 @@ int main(int argc, char **argv) {
                 overrideTheme = argv[++i];
             else if (strcmp(argv[i], "-n") == 0)
                 configurationLoaded = 1;
-            else if (strcmp(argv[i], "-v") == 0) {
+            else if (strcmp(argv[i], "-v") == 0 || strcmp(argv[i], "--version") == 0) {
                 fputs("IceWM " VERSION ", Copyright "
-		      "1997-2001 Marko Macek, 2001 Mathias Hasselmann\n",
+		      "1997-2002 Marko Macek, 2001 Mathias Hasselmann\n",
 		      stderr);
                 configurationLoaded = 1;
                 exit(0);
@@ -1368,6 +1400,19 @@ int main(int argc, char **argv) {
     }
 #endif
 
+#define DEPRECATE(x) \
+    do { \
+    if (x) warn("Deprecated option: " #x); \
+    } while (0);
+
+    DEPRECATE(warpPointer == true);
+    DEPRECATE(focusRootWindow == true);
+    DEPRECATE(replayMenuCancelClick == true);
+    DEPRECATE(manualPlacement == true);
+    DEPRECATE(strongPointerFocus == true);
+    //DEPRECATE(minimizeToDesktop == true);
+    DEPRECATE(showPopupsAbovePointer == true);
+
     if (workspaceCount == 0)
         addWorkspace(" 0 ");
 
