@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 
 #include "config.h"
@@ -432,14 +432,73 @@ void YFrameWindow::unmanage(bool reparent) {
     fClient = 0;
 }
 
+void YFrameWindow::getNewPos(const XConfigureRequestEvent &cr,
+                             int &cx, int &cy, int &cw, int &ch)
+{
+    cw = (cr.value_mask & CWWidth) ? cr.width : client()->width();
+    ch = (cr.value_mask & CWHeight) ? cr.height : client()->height();
+
+    int grav = NorthWestGravity;
+
+    XSizeHints *sh = client()->sizeHints();
+    if (sh && sh->flags & PWinGravity)
+        grav = sh->win_gravity;
+
+    int cur_x = x() + container()->x();
+    int cur_y = y() + container()->y();
+
+    //msg("%d %d %d %d", cr.x, cr.y, cr.width, cr.height);
+
+    if (cr.value_mask & CWX) {
+        if (grav == StaticGravity)
+            cx = cr.x;
+        else
+            cx = cr.x + container()->x();
+    } else {
+        if (grav == NorthGravity ||
+            grav == CenterGravity ||
+            grav == SouthGravity)
+        {
+            cx = cur_x + (client()->width() - cw) / 2;
+        } else if (grav == NorthEastGravity ||
+                   grav == EastGravity ||
+                   grav == SouthEastGravity)
+        {
+            cx = cur_x + (client()->width() - cw);
+        } else {
+            cx = cur_x;
+        }
+    }
+
+    if (cr.value_mask & CWY) {
+        if (grav == StaticGravity)
+            cy = cr.y;
+        else
+            cy = cr.y + container()->y();
+    } else {
+        if (grav == WestGravity ||
+            grav == CenterGravity ||
+            grav == EastGravity)
+        {
+            cy = cur_y + (client()->height() - ch) / 2;
+        } else if (grav == SouthEastGravity ||
+                   grav == SouthGravity ||
+                   grav == SouthWestGravity)
+        {
+            cy = cur_y + (client()->height() - ch);
+        } else {
+            cy = cur_y;
+        }
+    }
+}
+
 void YFrameWindow::configureClient(const XConfigureRequestEvent &configureRequest) {
     client()->setBorder((configureRequest.value_mask & CWBorderWidth) ? configureRequest.border_width : client()->getBorder());
-    int cx = (configureRequest.value_mask & CWX) ? configureRequest.x : x() + borderX();
-    int cy = (configureRequest.value_mask & CWY) ? configureRequest.y : y() + titleY() + borderY();
-    int cwidth = (configureRequest.value_mask & CWWidth) ? configureRequest.width : client()->width();
-    int cheight = (configureRequest.value_mask & CWHeight) ? configureRequest.height : client()->height();
 
-    configureClient(cx, cy, cwidth, cheight);
+    int cx, cy, cw, ch;
+    getNewPos(configureRequest, cx, cy, cw, ch);
+
+    configureClient(cx, cy, cw, ch);
 
     if (configureRequest.value_mask & CWStackMode) {
         YFrameWindow *sibling = 0;
@@ -467,7 +526,7 @@ void YFrameWindow::configureClient(const XConfigureRequestEvent &configureReques
                 setBelow(sibling);
                 break;
             default:
-                return ;
+                return;
             }
             XConfigureWindow(app->display(),
                              handle(),
@@ -524,8 +583,7 @@ void YFrameWindow::configureClient(int cx, int cy, int cwidth, int cheight) {
     cy -= borderY() + titleY();
     cwidth += 2 * borderX();
     cheight += 2 * borderY() + titleY();
-
-#if 0
+#if 1
     // !!! should be an option
     if (cx != x() || cy != y() ||
         (unsigned int)cwidth != width() || (unsigned int)cheight != height())
@@ -542,10 +600,9 @@ void YFrameWindow::configureClient(int cx, int cy, int cwidth, int cheight) {
 
     if (isIconic()) {
         cx += borderX();
-        cy += borderY();
+        cy += borderY() + titleY();
         cwidth -= 2 * borderX();
         cheight -= 2 * borderY() + titleY();
-
         client()->setGeometry(0, 0, cwidth, cheight);
 
         int nx = cx;
@@ -1017,8 +1074,7 @@ void YFrameWindow::wmMinimize() {
         setState(WinStateMinimized, WinStateMinimized);
         wmLower();
     }
-    if (clickFocus || !strongPointerFocus)
-        manager->focusTopWindow();
+    manager->focusTopWindow();
 }
 
 void YFrameWindow::minimizeTransients() {
@@ -1149,8 +1205,7 @@ void YFrameWindow::wmHide() {
 #endif
         setState(WinStateHidden, WinStateHidden);
     }
-    if (clickFocus || !strongPointerFocus)
-        manager->focusTopWindow();
+    manager->focusTopWindow();
 }
 
 void YFrameWindow::wmLower() {
@@ -1165,9 +1220,7 @@ void YFrameWindow::wmLower() {
             w = w->owner();
         }
         manager->restackWindows(this);
-
-        if (clickFocus || !strongPointerFocus)
-            manager->focusTopWindow();
+        manager->focusTopWindow();
     }
 }
 
@@ -1372,8 +1425,8 @@ void YFrameWindow::focus(bool canWarp) {
         setPosition(newX, newY);
     }
 
-    if (isFocusable())
-        manager->setFocus(this, canWarp);
+    //    if (isFocusable())
+    manager->setFocus(this, canWarp);
     if (raiseOnFocus && /* clickFocus && */ phase == phaseRunning)
         wmRaise();
 }
@@ -1663,7 +1716,7 @@ void YFrameWindow::getFrameHints() {
     MwmHints *mwm_hints = client()->mwmHints();
     int functions_only = (mwm_hints &&
                       (mwm_hints->flags & (MWM_HINTS_FUNCTIONS |
-                                           MWM_HINTS_FUNCTIONS))
+                                           MWM_HINTS_DECORATIONS))
                       == MWM_HINTS_FUNCTIONS);
 
     fFrameFunctions = 0;
@@ -1810,11 +1863,11 @@ void YFrameWindow::getDefaultOptions() {
 
 #ifndef LITE
 YIcon *newClientIcon(int count, int reclen, long * elem) {
-    YIcon::Image * small(NULL), * large(NULL), * huge(NULL);
+    YIcon::Image *small = NULL, *large = NULL, *huge = NULL;
     if (reclen < 2)
         return 0;
 
-    for (int i(0); i < count; i++, elem += reclen) {
+    for (int i = 0; i < count; i++, elem += reclen) {
         Pixmap pixmap(elem[0]), mask(elem[1]);
 
         if (pixmap == None) {
@@ -1899,12 +1952,16 @@ void YFrameWindow::updateIcon() {
     }
 
     if (fFrameIcon && !(fFrameIcon->small() || fFrameIcon->large())) {
-	delete fFrameIcon;
+        if (fFrameIcon->iconName() == 0)
+            delete fFrameIcon;
 	fFrameIcon = NULL;
     }
 
-    if (NULL == fFrameIcon) fFrameIcon = oldFrameIcon;
-    else if (oldFrameIcon != fFrameIcon) delete oldFrameIcon;
+    if (NULL == fFrameIcon) 
+        fFrameIcon = oldFrameIcon;
+    else if (oldFrameIcon != fFrameIcon) 
+         if (oldFrameIcon && oldFrameIcon->iconName() == 0) 
+             delete oldFrameIcon;
 
 // !!! BAH, we need an internal signaling framework
     if (menuButton()) menuButton()->repaint();
@@ -1954,6 +2011,10 @@ void YFrameWindow::addAsTransient() {
 
             fNextTransient = fOwner->transient();
             fOwner->setTransient(this);
+
+            if (getLayer() < fOwner->getLayer()) {
+                setLayer(fOwner->getLayer());
+            }
 	}
     }
 }
@@ -1962,7 +2023,7 @@ void YFrameWindow::removeAsTransient() {
     if (fOwner) {
         MSG(("removeAsTransient"));
 
-        for (YFrameWindow * curr(fOwner->transient()), * prev(NULL);
+        for (YFrameWindow *curr = fOwner->transient(), *prev = NULL;
 	     curr; prev = curr, curr = curr->nextTransient()) {
 	    if (curr == this) {
                 if (prev) prev->setNextTransient(nextTransient());
@@ -2039,7 +2100,7 @@ bool YFrameWindow::isFocusable() {
         return true;
     if (hints->input)
         return true;
-#if 1
+#if 0
     if (client()->protocols() & YFrameClient::wpTakeFocus)
         return true;
 #endif
@@ -2053,8 +2114,7 @@ void YFrameWindow::setWorkspace(long workspace) {
         fWinWorkspace = workspace;
         client()->setWinWorkspaceHint(fWinWorkspace);
         updateState();
-        if (clickFocus || !strongPointerFocus)
-            manager->focusTopWindow();
+        manager->focusTopWindow();
 #ifdef CONFIG_TASKBAR
         updateTaskBar();
 #endif
@@ -2065,6 +2125,10 @@ void YFrameWindow::setLayer(long layer) {
     if (layer >= WinLayerCount || layer < 0)
         return ;
 
+    if (fOwner)
+        if (layer < fOwner->getLayer())
+            return;
+
     if (layer != fWinLayer) {
         long oldLayer = fWinLayer;
 
@@ -2074,6 +2138,14 @@ void YFrameWindow::setLayer(long layer) {
         client()->setWinLayerHint(fWinLayer);
         manager->restackWindows(this);
 
+        YFrameWindow *w = transient();
+
+        while (w) {
+            if (w->getLayer() < layer)
+                w->setLayer(layer); /* !!! need to implement WinLayerInherit !!! */
+            w = w->nextTransient();
+        }
+
         if (limitByDockLayer &&
 	   (getLayer() == WinLayerDock ||
 	      oldLayer == WinLayerDock))
@@ -2343,8 +2415,7 @@ void YFrameWindow::setState(long mask, long state) {
 #ifdef CONFIG_TASKBAR
         updateTaskBar();
 #endif
-        if (clickFocus || !strongPointerFocus)
-            manager->focusTopWindow();
+        manager->focusTopWindow();
     }
     if ((fOldState ^ fNewState) & WinStateRollup) {
         MSG(("WinStateRollup: %d", isRollup()));
@@ -2441,9 +2512,9 @@ void YFrameWindow::updateMwmHints() {
         tt = 0;
 
     if (!isRollup() && !isIconic()) /// !!! check (emacs hates this)
-        configureClient(x() + bx - borderX() + borderX(),
-                y() + by - borderY() + tt + borderY() + titleY(),
-                client()->width(), client()->height());
+        configureClient(x() + bx + bx - borderX(),
+                        y() + by + by - borderY() + titleY(),
+                        client()->width(), client()->height());
 }
 
 #ifndef LITE
@@ -2542,8 +2613,7 @@ void YFrameWindow::handleMsgBox(YMsgBox *msgbox, int operation) {
         if (fKillMsgBox) {
             manager->unmanageClient(fKillMsgBox->handle());
             fKillMsgBox = 0;
-            if (clickFocus || !strongPointerFocus)
-                manager->focusTopWindow();
+            manager->focusTopWindow();
         }
         if (operation == YMsgBox::mbOK)
             wmKill();
