@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 #include "yfull.h"
@@ -513,7 +513,7 @@ void YWindowManager::handleClientMessage(const XClientMessageEvent &message) {
 }
 
 Window YWindowManager::findWindow(char const * resource) {
-    char *wmInstance(0), *wmClass(0);
+    char *wmInstance = 0, *wmClass = 0;
 
     char const * dot(resource ? strchr(resource, '.') : 0);
 
@@ -632,7 +632,7 @@ void YWindowManager::setFocus(YFrameWindow *f, bool /*canWarp*/) {
     }
 #endif
 
-    if (input) {
+    if (input || w == desktop->handle()) {
         XSetInputFocus(app->display(), w, RevertToNone, CurrentTime);
     }
 
@@ -765,8 +765,7 @@ void YWindowManager::manageClients() {
         XFree(winClients);
     updateWorkArea();
     phase = phaseRunning;
-    if (clickFocus || !strongPointerFocus)
-        focusTopWindow();
+    focusTopWindow();
 }
 
 void YWindowManager::unmanageClients() {
@@ -1047,8 +1046,10 @@ canActivate
 ) {
     YFrameClient *client = frame->client();
 
-    int posWidth = client->width() + 2 * frame->borderX();
-    int posHeight = client->height() + 2 * frame->borderY() + frame->titleY();
+    int frameWidth = 2 * frame->borderX();
+    int frameHeight = 2 * frame->borderY() + frame->titleY();
+    int posWidth = client->width() + frameWidth;
+    int posHeight = client->height() + frameHeight;
 
 #ifdef CONFIG_SESSION
     if (app->haveSessionManager() && findWindowInfo(frame)) {
@@ -1063,38 +1064,55 @@ canActivate
         WindowOption wo;
         frame->getWindowOptions(wo, true);
 
-        //msg("positioning %d %d %d %d %d", wo.gx, wo.gy, wo.gw, wo.gh, wo.gflags);
+        //msg("positioning %d %d %d %d %X", wo.gx, wo.gy, wo.gw, wo.gh, wo.gflags);
         if (wo.gh != 0 && wo.gw != 0) {
             if (wo.gflags & (WidthValue | HeightValue))
-                frame->setSize(wo.gw, wo.gh);
+                frame->setSize(wo.gw + frameWidth,
+                               wo.gh + frameHeight);
         }
         if (wo.gflags & (XValue | YValue)) {
-            frame->setPosition(wo.gx, wo.gy);
-            return ;
+            int wox = wo.gx;
+            int woy = wo.gy;
+
+            if (wo.gflags & XNegative)
+                wox = desktop->width() - frame->width() - wox;
+            if (wo.gflags & YNegative)
+                woy = desktop->height() - frame->height() - woy;
+            frame->setPosition(wox, woy);
+            return;
         }
     }
 #endif
 
-    if (newClient && client->adopted() && client->sizeHints() &&
-        (!(client->sizeHints()->flags & (USPosition | PPosition)) ||
-         ((client->sizeHints()->flags & PPosition) &&
-          frame->frameOptions() & YFrameWindow::foIgnorePosition))) {
-        getNewPosition(frame, x, y, posWidth, posHeight);
-        newClient = false;
-    }
-
     int posX = x;
     int posY = y;
 
-    if (1) {
-        int gx, gy;
+    if (newClient && client->adopted() && client->sizeHints() &&
+        (!(client->sizeHints()->flags & (USPosition | PPosition)) ||
+         ((client->sizeHints()->flags & PPosition) &&
+          frame->frameOptions() & YFrameWindow::foIgnorePosition)))
+    {
+        getNewPosition(frame, x, y, posWidth, posHeight);
+        posX = x;
+        posY = y;
+        newClient = false;
+    } else {
+        if (client->sizeHints() &&
+            (client->sizeHints()->flags & PWinGravity) &&
+            client->sizeHints()->win_gravity == StaticGravity)
+        {
+            posX -= frame->borderX();
+            posY -= frame->borderY() + frame->titleY();
+        } else {
+            int gx, gy;
 
-        client->gravityOffsets(gx, gy);
+            client->gravityOffsets(gx, gy);
 
-        if (gx > 0)
-            posX -= 2 * frame->borderX() - 1 - client->getBorder();
-        if (gy > 0)
-            posY -= 2 * frame->borderY() + frame->titleY() - 1 - client->getBorder();
+            if (gx > 0)
+                posX -= 2 * frame->borderX() - 1 - client->getBorder();
+            if (gy > 0)
+                posY -= 2 * frame->borderY() + frame->titleY() - 1 - client->getBorder();
+        }
     }
 
     MSG(("mapping geometry (%d:%d %dx%d)", posX, posY, posWidth, posHeight));
@@ -1345,6 +1363,10 @@ void YWindowManager::destroyedClient(Window win) {
 void YWindowManager::focusTopWindow() {
     if (phase != phaseRunning)
         return ;
+    if (!clickFocus && strongPointerFocus) {
+        XSetInputFocus(app->display(), PointerRoot, RevertToNone, CurrentTime);
+        return ;
+    }
     if (!focusTop(topLayer(WinLayerNormal)))
         focusTop(topLayer());
 }
@@ -1661,6 +1683,9 @@ void YWindowManager::resizeWindows() {
 
 void YWindowManager::activateWorkspace(long workspace) {
     if (workspace != fActiveWorkspace) {
+
+        XSetInputFocus(app->display(), desktop->handle(), RevertToNone, CurrentTime);
+
 #ifdef CONFIG_TASKBAR
         if (taskBar && taskBar->workspacesPane() &&
 	    fActiveWorkspace != (long)WinWorkspaceInvalid) {
@@ -1708,16 +1733,7 @@ void YWindowManager::activateWorkspace(long workspace) {
 #endif
             }
 
-        if ((clickFocus || !strongPointerFocus)
-            /* && (getFocus() == 0 || !getFocus()->visibleNow() || !getFocus()->isFocusable())*/)
-        {
-            focusTopWindow();
-        } else {
-            if (strongPointerFocus) {
-                XSetInputFocus(app->display(), PointerRoot, RevertToNone, CurrentTime);
-
-            }
-        }
+        focusTopWindow();
         resetColormap(true);
 
 #ifdef CONFIG_TASKBAR
@@ -2139,8 +2155,7 @@ void YWindowManager::undoArrange() {
         }
         delete [] fArrangeInfo; fArrangeInfo = 0;
         fArrangeCount = 0;
-        if (clickFocus || !strongPointerFocus)
-            focusTopWindow();
+        focusTopWindow();
     }
 }
 
