@@ -13,6 +13,9 @@ struct WindowOption {
     unsigned long options, option_mask;
     long workspace;
     long layer;
+#ifdef CONFIG_TRAY
+    long tray;
+#endif
     int gflags;
     int gx, gy;
     unsigned gw, gh;
@@ -39,8 +42,6 @@ extern char *winOptFile;
 
 void loadWinOptions(const char *optFile);
 
-char *getArgument(char *dest, int maxLen, char *p, bool comma);
-
 #endif
 
 #endif
