@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 
@@ -453,7 +453,7 @@ bool StartMenu::handleKey(const XKeyEvent &key) {
         KeySym k = XKeycodeToKeysym(app->display(), key.keycode, 0);
         int m = KEY_MODMASK(key.state);
         
-        if (((k == XK_Meta_L) || (k == XK_Alt_L)) && m == 0) {
+        if (((k == app->Win_L) || (k == app->Win_R)) && m == 0) {
             cancelPopup();
             return true;
         }
