@@ -26,12 +26,20 @@ public:
     void cancel();
     void accept();
     void displayFocus(YFrameWindow *frame);
+
 private:
     YFrameWindow *fActiveWindow;
     YFrameWindow *fLastWindow;
 
+    int fIconCount, fIconOffset;
+
+#ifdef CONFIG_GRADIENTS
+    class YPixbuf * fGradient;
+#endif
+
     static YColor *switchFg;
     static YColor *switchBg;
+    static YColor *switchHl;
     static YFont *switchFont;
 
     int modsDown;
@@ -40,10 +48,14 @@ private:
 
     bool modDown(int m);
     bool isModKey(KeyCode c);
+    void resize();
 };
 
-extern SwitchWindow *switchWindow;
+extern SwitchWindow * switchWindow;
+extern YPixmap * switchbackPixmap;
 
-extern YPixmap *switchbackPixmap;
+#ifdef CONFIG_GRADIENTS
+extern class YPixbuf * switchbackPixbuf;
+#endif
 
 #endif
