@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1998-2001 Marko Macek
+ * Copyright (C) 1998-2002 Marko Macek
  */
 #include "config.h"
 #include "yfull.h"
@@ -15,6 +15,8 @@
 #include "prefs.h"
 #include "ypixbuf.h"
 
+#include <sys/resource.h>
+
 #include "intl.h"
 
 #ifdef CONFIG_SESSION
@@ -646,13 +648,22 @@ bool YApplication::hasColormap() {
     pattern.screen = DefaultScreen(display());
 
     int nVisuals;
-    XVisualInfo * visual(XGetVisualInfo(display(), VisualScreenMask,
-    					&pattern, &nVisuals));
+    bool rc = false;
 
-    while(visual && nVisuals--)
-	if ((visual++)->c_class & 1) return true;
+    XVisualInfo *first_visual(XGetVisualInfo(display(), VisualScreenMask,
+                                              &pattern, &nVisuals));
+    XVisualInfo *visual = first_visual;
 
-    return false;
+    while(visual && nVisuals--) {
+	if (visual->c_class & 1)
+            rc = true;
+        visual++;
+    }
+
+    if (first_visual)
+        XFree(first_visual);
+
+    return rc;
 }
 
 void YApplication::registerTimer(YTimer *t) {
@@ -1334,8 +1345,8 @@ void YApplication::initModifiers() {
         WinMask = MetaMask;
 	
 	if (win95keys) {
-            Win_L = XK_Meta_L;
-            Win_R = XK_Meta_R;
+            Win_L = XK_Super_L;
+            Win_R = XK_Super_R;
 	}
     }
 
@@ -1367,6 +1378,28 @@ void YApplication::runProgram(const char *str, const char *const *args) {
         if (open("/dev/null", O_RDONLY) != 0)
             _exit(1);
 #endif
+#if 1   /* for now, some debugging code */
+        {
+            /* close all files */
+
+            int             i, max = 1024;
+            struct rlimit   lim;
+
+            if (getrlimit(RLIMIT_NOFILE, &lim) == 0)
+                max = lim.rlim_max;
+
+            for (i = 3; i < max; i++) {
+                int fl;
+                if (fcntl(i, F_GETFD, &fl) == 0) {
+                    if (!(fl & FD_CLOEXEC)) {
+                        warn("file descriptor still open: %d. Please report a bug!", i);
+                    }
+                }
+                close (i);
+            }
+        }
+#endif
+
         if (args)
             execvp(str, (char **)args);
         else
