@@ -5,6 +5,7 @@
 
 #include "ywindow.h"
 #include "ycursor.h"
+#include "ypaths.h"
 
 class YTimer;
 class YSocket;
@@ -19,9 +20,15 @@ public:
     void exitLoop(int exitCode);
     void exit(int exitCode);
     
-    //YRootWindow *root() { return fRoot; }
-    Display *display() const { return fDisplay; }
-    bool detectGNOME();
+    Display * display() const { return fDisplay; }
+    int screen() { return DefaultScreen (display()); }
+    Visual * visual() { return DefaultVisual(display(), screen()); }
+    Colormap colormap() { return DefaultColormap(display(), screen()); }
+    unsigned depth() { return DefaultDepth(display(), screen()); }
+    char const * executable() { return fExecutable; }
+
+    bool hasColormap();
+    bool hasGNOME();
 
     void saveEventTime(XEvent &xev);
     Time getEventTime() const { return lastEventTime; }
@@ -53,12 +60,14 @@ public:
 
     void initModifiers();
 
+    void alert();
+
     void runProgram(const char *str, const char *const *args);
     void runCommand(const char *prog);
 
-    static char *findConfigFile(const char *name);
-
-#ifdef SM
+    static char * findConfigFile(const char *name);
+    
+#ifdef CONFIG_SESSION
     bool haveSessionManager();
     virtual void smSaveYourself(bool shutdown, bool fast);
     virtual void smSaveYourselfPhase2();
@@ -72,12 +81,14 @@ public:
 
     void setClipboardText(char *data, int len);
 
-    bool hasColormap();
-
     static YCursor leftPointer;
     static YCursor rightPointer;
     static YCursor movePointer;
 
+#ifndef LITE
+    static YResourcePaths iconPaths;
+#endif
+
     unsigned int AltMask;
     unsigned int MetaMask;
     unsigned int NumLockMask;
@@ -86,6 +97,10 @@ public:
     unsigned int HyperMask;
     unsigned int ModeSwitchMask;
 
+    unsigned int WinMask;
+    unsigned int Win_L;
+    unsigned int Win_R;
+
     unsigned int KeyMask;
     unsigned int ButtonMask;
     unsigned int ButtonKeyMask;
@@ -112,6 +127,8 @@ private:
     int fExitLoop;
     int fExitCode;
     int fExitApp;
+    
+    char const * fExecutable;
 
     friend class YTimer;
     friend class YSocket;
