@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997,1998 Marko Macek
+ * Copyright (C) 1997-2001 Marko Macek
  */
 #include "config.h"
 
@@ -16,6 +16,8 @@
 
 #include <string.h>
 
+#include "intl.h"
+
 YFont *YInputLine::inputFont = 0;
 YColor *YInputLine::inputBg = 0;
 YColor *YInputLine::inputFg = 0;
@@ -48,12 +50,12 @@ YInputLine::YInputLine(YWindow *parent): YWindow(parent) {
             actionPasteSelection = new YAction();
             actionSelectAll = new YAction();
             inputMenu->setActionListener(this);
-            inputMenu->addItem("Cut", 2, "Ctrl+X", actionCut)->setEnabled(true);
-            inputMenu->addItem("Copy", 0, "Ctrl+C", actionCopy)->setEnabled(true);
-            inputMenu->addItem("Paste", 0, "Ctrl+V", actionPaste)->setEnabled(true);
-            inputMenu->addItem("Paste Selection", 6, 0, actionPasteSelection)->setEnabled(true);
+            inputMenu->addItem(_("Cu_t"), -2, _("Ctrl+X"), actionCut)->setEnabled(true);
+            inputMenu->addItem(_("_Copy"), -2, _("Ctrl+C"), actionCopy)->setEnabled(true);
+            inputMenu->addItem(_("_Paste"), -2, _("Ctrl+V"), actionPaste)->setEnabled(true);
+            inputMenu->addItem(_("Paste _Selection"), -2, 0, actionPasteSelection)->setEnabled(true);
             inputMenu->addSeparator();
-            inputMenu->addItem("Select All", 7, "Ctrl+A", actionSelectAll);
+            inputMenu->addItem(_("Select _All"), -2, _("Ctrl+A"), actionSelectAll);
         }
     }
 
@@ -583,13 +585,13 @@ bool YInputLine::insertChar(char ch) {
     return true;
 }
 
-#define CHCLASS(c) (((c) == ' ') ? 1 : 0)
+#define CHCLASS(c) ((c) == ' ')
 
 int YInputLine::nextWord(int p, bool sep) {
     int textLen = fText ? strlen(fText) : 0;
 
     while (p < textLen && (CHCLASS(fText[p]) == CHCLASS(fText[p + 1]) ||
-                           !sep && CHCLASS(fText[p]) == 1))
+                           !sep && CHCLASS(fText[p])))
         p++;
     if (p < textLen)
         p++;
@@ -600,7 +602,7 @@ int YInputLine::prevWord(int p, bool sep) {
     if (p > 0 && !sep)
         p--;
     while (p > 0 && (CHCLASS(fText[p]) == CHCLASS(fText[p - 1]) ||
-                     !sep && CHCLASS(fText[p]) == 1))
+                     !sep && CHCLASS(fText[p])))
         p--;
     return p;
 }
