@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 #include "ylib.h"
@@ -12,6 +12,7 @@
 #include "sysdep.h"
 #include "ystring.h"
 #include "prefs.h"
+#include "stdio.h"
 
 #include "intl.h"
 
@@ -460,6 +461,21 @@ YXftFont::YXftFont(const char *name):
 	    --fFontCount;
 	}
 
+#if 0
+        if (strstr(xlfd, "koi") != 0) {
+            msg("font %s", xlfd);
+            for (int c = 0; c < 0x500; c++) {
+                if ((c % 64) == 0) {
+                    printf("\n%04X ", c);
+                }
+                int ok = XftGlyphExists(app->display(), font, c);
+                printf("%c", ok ? 'X' : '.');
+                if ((c % 8) == 7)
+                    printf(" ");
+            }
+            printf("\n");
+        }
+#endif
 	delete[] xlfd;
     }
 
@@ -577,6 +593,7 @@ YXftFont::TextPart * YXftFont::partitions(char_t * str, size_t len,
 		} else {
 		    parts[nparts].font = NULL;
 		    parts[nparts].width = 0;
+                    warn("glyph not found: %d", *(c - 1));
 		}
 
 		return parts;
@@ -826,8 +843,8 @@ struct YRotated {
 
 
 	static void rotate(XImage * src, XImage * dst) {
-	    for (int sy(src->height - 1), dx(0); sy >= 0; --sy, ++dx)
-		for (int sx(src->width - 1), & dy(sx); sx >= 0; --sx)
+	    for (int sy = src->height - 1, dx = 0; sy >= 0; --sy, ++dx)
+		for (int sx = src->width - 1, &dy = sx; sx >= 0; --sx)
 		    XPutPixel(dst, dx, dy, XGetPixel(src, sx, sy));
 	}
     };
@@ -842,8 +859,8 @@ struct YRotated {
 	static T height(T const & w, T const & /*h*/) { return w; }
 
 	static void rotate(XImage * src, XImage * dst) {
-	    for (int sy(src->height - 1), & dx(sy); sy >= 0; --sy)
-	        for (int sx(src->width - 1), dy(0); sx >= 0; --sx, ++dy)
+	    for (int sy = src->height - 1, &dx = sy; sy >= 0; --sy)
+	        for (int sx = src->width - 1, dy = 0; sx >= 0; --sx, ++dy)
 		    XPutPixel(dst, dx, dy, XGetPixel(src, sx, sy));
 	}
     };
@@ -1285,11 +1302,11 @@ void Graphics::drawGradient(const class YPixbuf & pixbuf,
 void Graphics::drawArrow(Direction direction, int x, int y, int size,
 			 bool pressed) {
     YColor *nc(color());
-    YColor *oca(pressed ? nc->darker() : nc->brighter()),
-	   *ica(pressed ? YColor::black : nc),
-    	   *ocb(pressed ? wmLook == lookGtk ? nc : nc->brighter()
-			: nc->darker()),
-	   *icb(pressed ? nc->brighter() : YColor::black);
+    YColor *oca = pressed ? nc->darker() : nc->brighter(),
+	   *ica = pressed ? YColor::black : nc,
+    	   *ocb = pressed ? wmLook == lookGtk ? nc : nc->brighter()
+			: nc->darker(),
+	   *icb = pressed ? nc->brighter() : YColor::black;
 
     XPoint points[3];
 
