@@ -2,7 +2,7 @@
  *  IceWM - Implementation of a RGB pixel buffer encapsulating
  *  libxpm and Imlib plus a scaler for RGB pixel buffers
  *
- *  Copyright (C) 2001 The Authors of IceWM
+ *  Copyright (C) 2002 The Authors of IceWM
  *
  *  Released under terms of the GNU Library General Public License
  *
@@ -780,6 +780,7 @@ YPixbuf::YPixbuf(char const * filename, bool fullAlpha):
     fWidth(0), fHeight(0), fRowStride(0),
     fPixels(NULL), fAlpha(NULL), fPixmap(None) {
     XpmAttributes xpmAttributes;
+    memset(&xpmAttributes, 0, sizeof(xpmAttributes));
     xpmAttributes.colormap  = app->colormap();
     xpmAttributes.closeness = 65535;
     xpmAttributes.valuemask = XpmSize|XpmReturnPixels|XpmColormap|XpmCloseness;
@@ -803,6 +804,7 @@ YPixbuf::YPixbuf(char const * filename, bool fullAlpha):
         } else
             fPixels = copyImageToPixbuf<3>(*image, fRowStride);
 
+        XpmFreeAttributes(&xpmAttributes);
     } else
         warn(_("Loading of pixmap \"%s\" failed: %s"),
                filename, XpmGetErrorString(rc));
@@ -857,6 +859,7 @@ YPixbuf::YPixbuf(Drawable drawable, Pixmap mask,
     h = min(h, dHeight - y);
 
     MSG(("YPixbuf::YPixbuf: after clipping: x=%i, y=%i; w=%i, h=%i", x, y, w, h));
+    if (!(w && h)) return;
 
     XImage * image(XGetImage(app->display(), drawable, x, y, w, h,
                              AllPlanes, ZPixmap));
