@@ -1,7 +1,7 @@
 /*
  * IceWM
  *
- * Copyright (C) 1997-2001 Marko Macek
+ * Copyright (C) 1997-2002 Marko Macek
  */
 #include "config.h"
 #include "yfull.h"
@@ -214,12 +214,14 @@ Graphics &YWindow::getGraphics() {
 
 void YWindow::repaint() {
 //    if ((flags & (wfCreated | wfVisible)) == (wfCreated | wfVisible)) {
-    if (viewable()) paint(getGraphics(), 0, 0, width(), height());
+    if (viewable()) 
+        paint(getGraphics(), 0, 0, width(), height());
 }
 
 void YWindow::repaintFocus() {
 //    if ((flags & (wfCreated | wfVisible)) == (wfCreated | wfVisible)) {
-    if (viewable()) paintFocus(getGraphics(), 0, 0, width(), height());
+    if (viewable())
+        paintFocus(getGraphics(), 0, 0, width(), height());
 }
 
 void YWindow::create() {
@@ -452,9 +454,11 @@ void YWindow::handleEvent(const XEvent &event) {
     switch (event.type) {
     case KeyPress:
     case KeyRelease:
-        for (YWindow *w = this; // !!! hack, fix
-	     w && w->handleKey(event.xkey) == false;
-	     w = w->parent());
+        {
+            for (YWindow *w = this; // !!! hack, fix
+                 w && w->handleKey(event.xkey) == false;
+                 w = w->parent());
+        }
         break;
 
     case ButtonPress:
@@ -757,9 +761,21 @@ void YWindow::handleMotion(const XMotionEvent &motion) {
             int const dx(abs(motion.x_root - fClickEvent.x_root));
             int const dy(abs(motion.y_root - fClickEvent.y_root));
             int const motionDelta(max(dx, dy));
+            int curButtons = 0;
 
-            if ((motion.time - fClickTime > (unsigned) ClickMotionDelay) ||
-                (motionDelta >= ClickMotionDistance)) {
+            curButtons =
+                ((motion.state & Button1Mask) ? (1 << 1) : 0) |
+                ((motion.state & Button2Mask) ? (1 << 2) : 0) |
+                ((motion.state & Button3Mask) ? (1 << 3) : 0) |
+                ((motion.state & Button4Mask) ? (1 << 4) : 0) |
+                ((motion.state & Button5Mask) ? (1 << 5) : 0);
+
+            if (((motion.time - fClickTime > (unsigned) ClickMotionDelay) ||
+                (motionDelta >= ClickMotionDistance)) &&
+                ((1 << fClickButton) == curButtons)
+               )
+            {
+                //msg("start drag %d %d %d", curButtons, fClickButton, motion.state);
                 fClickDrag = 1;
                 handleBeginDrag(fClickEvent, motion);
             }
@@ -1073,6 +1089,8 @@ void YWindow::requestFocus() {
         parent()->setFocus(this);
         setFocus(0);///???!!! is this the right place?
     }
+    if (parent() && parent()->isFocused())
+        setWindowFocus();
 }
 
 
@@ -1187,8 +1205,8 @@ void YWindow::setFocus(YWindow *window) {
     }
 }
 void YWindow::gotFocus() {
-    if (parent() && parent()->isFocused())
-        setWindowFocus();
+    if (fFocusedWindow)
+        fFocusedWindow->gotFocus();
     repaintFocus();
 }
 
@@ -1471,10 +1489,10 @@ void YWindow::grabVKey(int key, unsigned int vm) {
             m = app->WinMask;
             if (vm & kfShift)
                 m |= ShiftMask;
-           if (vm & kfSuper)
-               m |= app->SuperMask;
-           if (vm & kfHyper)
-               m |= app->HyperMask;
+            if (vm & kfSuper)
+                m |= app->SuperMask;
+            if (vm & kfHyper)
+                m |= app->HyperMask;
             grabKey(key, m);
         }
     }
@@ -1484,6 +1502,14 @@ unsigned int YWindow::VMod(int m) {
     int vm = 0;
     int m1 = m & ~app->WinMask;
 
+    if (m & app->WinMask) {
+        if (modMetaIsCtrlAlt) {
+            vm |= kfCtrl + kfAlt;
+        } else if (app->WinMask == app->MetaMask) {
+            vm |= kfMeta;
+        }
+    }
+
     if (m1 & ShiftMask)
         vm |= kfShift;
     if (m1 & ControlMask)
@@ -1497,21 +1523,22 @@ unsigned int YWindow::VMod(int m) {
     if (m1 & app->HyperMask)
        vm |= kfHyper;
 
-    if (modMetaIsCtrlAlt && (m & app->WinMask))
-            vm |= kfCtrl + kfAlt;
-    //&& (vm & (kfCtrl | kfAlt | kfMeta)) == kfMeta)
-    //vm = (vm & ~kfMeta) | kfCtrl | kfAlt;
-
     return vm;
 }
 
 bool YWindow::getCharFromEvent(const XKeyEvent &key, char *c) {
-    int klen;
     char keyBuf[1];
     KeySym ksym;
     XKeyEvent kev = key;
 
-    klen = XLookupString(&kev, keyBuf, 1, &ksym, NULL);
+    // FIXME:
+    int klen = XLookupString(&kev, keyBuf, 1, &ksym, NULL);
+#ifndef USE_XmbLookupString
+    if ((klen == 0)  && (ksym < 0x1000)) {
+        klen = 1;
+        keyBuf[0] = ksym & 0xFF;
+    }
+#endif
     if (klen == 1) {
         *c = keyBuf[0];
         return true;
