@@ -3,8 +3,8 @@
 #cvs () { echo cvs $* }
 
 CVSROOT=':pserver:anonymous@cvs.icewm.sourceforge.net:/cvsroot/icewm'
-MODULE='icewm-1.0'
-SRCDIR="$MODULE/$MODULE"
+MODULE='icewm-1.2'
+SRCDIR="$MODULE"
 
 if [ -d "$MODULE" ]; then
   pushd $MODULE > /dev/null
@@ -41,13 +41,10 @@ rm config.{cache,log,status}
 
 RELEASE=`sed -ne 's/^%define\>[[:space:]]*release\>[[:space:]]*\<\(.*\)$/\1/p'\
 	< icewm.spec`
-TARBALL="icewm-$VERSION-$RELEASE.tar"
+TARBALL="icewm-$VERSION.tar"
 
 popd
 echo Building tarball $TARBALL
 tar -cf $TARBALL --exclude=CVS $DISTDIR
 gzip -9 < $TARBALL > "$TARBALL.gz"
-bzip2 -9 < $TARBALL > "$TARBALL.bz2"
-cp -v "$TARBALL.bz2" "$HOME/rpm/SOURCES/"
-ln -sf "$TARBALL.gz" "icewm-$VERSION.tar.gz"
-ln -sf "$TARBALL.bz2" "icewm-$VERSION.tar.bz2"
+cp -v "$TARBALL.gz" "$HOME/rpm/SOURCES/"
